# global imports
import matplotlib
import matplotlib.pyplot as plt
import numpy as np
from math import pi

#local imports
from LoadCSVMat import LoadCSVMat


########### Figure presets ########

plotSizeInch=(3.35, 3.75);

###font
##plt.rc('text', usetex=True);
##plt.rc('font', family='serif');
##plt.rc('font', serif='Computer Modern Roman');
##plt.rc('xtick', labelsize=10.5);
##plt.rc('ytick', labelsize=10.5);
##plt.rc('axes', labelsize=10.5);
##
###line thickness ticks
##axisLineWidthPt=0.850;
##plt.rc('axes', linewidth=axisLineWidthPt);
##plt.rc('lines', linewidth=axisLineWidthPt);
##plt.rc('xtick.major', size=6.1, pad=2, width=axisLineWidthPt);
##plt.rc('xtick.minor', size=4, pad=2, width=axisLineWidthPt);
##plt.rc('ytick.major', size=6.1, pad=2, width=axisLineWidthPt);
##plt.rc('ytick.minor', size=4, pad=2, width=axisLineWidthPt);
##
##plt.rc('figure', figsize=plotSizeInch);#in inch
##
### keep fonts as fonts
##matplotlib.rcParams['svg.fonttype'] = 'none';

############ Data load ########

# load the data for the T as a function of frequency for
# different temperatures
# NB! T in %, extracted from Origin
linTMat=LoadCSVMat('LinT_percent_4K2_5K_6K_7K_8K_9K_10K_11K.csv');

# intensity-dependent transmission
# in %
dTOvTIntDepMat=LoadCSVMat('PowSweep_4K2_500uW_376uW_251uW_175uW.csv');


########## Plotting ############

# box for the plot
#absolute measurements (convinent)
topMarginInch=0.087;
rightMarginInch=0.092;
leftMarginInch=0.523;
botMarginInch=0.32;
#relative to page size (needed by software)
rectLeft=leftMarginInch/plotSizeInch[0];
rectRight=1-rightMarginInch/plotSizeInch[0];
rectBot=botMarginInch/plotSizeInch[1];
rectTop=1-topMarginInch/plotSizeInch[1];

fig, (ax1, ax2)=plt.subplots(2, sharex=True, sharey=False);
############### subplot 1
ax1.plot(linTMat[:,0], linTMat[:,1::]);
ax1.set_ylim((0,8));#%

# x-axis
xLim=(92,102); ax1.set_xlim(xLim);#GHz
xTickOffset=0;#offset of the first tick after minimum
xTickStep=1;
xTicks=np.arange(start=xLim[0]+xTickOffset, stop=xLim[1]+xTickStep, step=xTickStep);
ax1.set_xticks(xTicks);

# y-axis
y1Lim=(0,8); ax1.set_ylim(y1Lim);#GHz
y1TickOffset=0;#offset of the first tick after minimum
y1TickStep=1;
y1Ticks=np.arange(start=y1Lim[0]+y1TickOffset, stop=y1Lim[1]+y1TickStep, step=y1TickStep);
ax1.set_yticks(y1Ticks);
ax1.set_ylabel('Transmission, T (\\%)');

############### subplot 2
ax2.plot(dTOvTIntDepMat[:,0], dTOvTIntDepMat[:,1::]);
ax2.set_ylim((-9,9));#%

# x-axis
xLim=(92,102); ax1.set_xlim(xLim);#GHz
xTickOffset=0;#offset of the first tick after minimum
xTickStep=1;
xTicks=np.arange(start=xLim[0]+xTickOffset, stop=xLim[1]+xTickStep, step=xTickStep);
ax1.set_xticks(xTicks);
ax2.set_xlabel('Frequency, $\\nu$ (GHz)');

# y-axis
y2Lim=(-9,9); ax1.set_ylim(y1Lim);#GHz
y2TickOffset=1;#offset of the first tick after minimum
y2TickStep=2;
y2Ticks=np.arange(start=y2Lim[0]+y2TickOffset, stop=y2Lim[1], step=y2TickStep);
ax2.set_yticks(y2Ticks);
ax2.set_ylabel('$\\Delta$T/T (\\%)');

################ overall
fig.subplots_adjust(hspace=0);# join two figures
fig.subplots_adjust(left=rectLeft, right=rectRight, bottom=rectBot, top=rectTop);#set size


# first save
# I can get proper lines from PDF and proper writing, including TEX from SVG
##fig.savefig('Raw_LinNonLinFqSweep.pdf', transparent=True);
##fig.savefig('Raw_LinNonLinFqSweep.svg', transparent=True);
# then show the results
plt.show();


