# global imports
import matplotlib
import matplotlib.pyplot as plt
import numpy as np
from math import pi

#local imports
from LoadCSVMat import LoadCSVMat


########### Figure presets ########

plotSizeInch=(3.35, 3.75);

#font
plt.rc('text', usetex=True);
plt.rc('font', family='serif');
plt.rc('font', serif='Computer Modern Roman');
plt.rc('xtick', labelsize=10.5);
plt.rc('ytick', labelsize=10.5);
plt.rc('axes', labelsize=10.5);

#line thickness ticks (in pt)
plt.rc('axes', linewidth=0.850);
plt.rc('lines', linewidth=0.850);
plt.rc('xtick.major', size=6.1, pad=2);
plt.rc('xtick.minor', size=4, pad=2);
plt.rc('ytick.major', size=6.1, pad=2);
plt.rc('ytick.minor', size=4, pad=2);

plt.rc('figure', figsize=plotSizeInch);#in inch

# keep fonts as fonts
matplotlib.rcParams['svg.fonttype'] = 'none';

############ Data load ########

# load the data for the dT/T as a function of temperature
dToverTMat=LoadCSVMat('ThetaSweep_97GHz_500uW_376uW_251uW_125uW.csv');

# intensity-dependent phase change
# from 'Analyze_PowerSweepsAtFixedFq_ThetaSweep_PowerCorr_n2_extract.m'
# three columns, temperature, phase diff extracted by subtraction
# and phse difference extracted by linear fitting and then
# multiplying the gradient by the intensity range
intDepPhaseDiffMat=LoadCSVMat('IntensityDepPhaseChangeV2_confLim_97GHz_112.4uW_cm2_500.0uW_cm2.csv');


########## Plotting ############

# box for the plot
#absolute measurements (convinent)
topMarginInch=0.087;
rightMarginInch=0.092;
leftMarginInch=0.523;
botMarginInch=0.32;
#relative to page size (needed by software)
rectLeft=leftMarginInch/plotSizeInch[0];
rectRight=1-rightMarginInch/plotSizeInch[0];
rectBot=botMarginInch/plotSizeInch[1];
rectTop=1-topMarginInch/plotSizeInch[1];

fig, (ax1, ax2)=plt.subplots(2, sharex=True, sharey=False);
# subplot 1
ax1.plot(dToverTMat[:,0], dToverTMat[:,1::]);
ax1.set_ylim((-10,1));
ax1.set_ylabel('$\\Delta$T/T (\%)');
# subplot 2
ax2.errorbar(intDepPhaseDiffMat[:,0], intDepPhaseDiffMat[:,3]/1e-3, intDepPhaseDiffMat[:,4]/1e-3, fmt='.')

ax2.set_xlabel('Temperature, $\\theta$ (K)');
ax2.set_ylabel('$\\Phi_{500\\mu\\mathrm{W}/\\mathrm{cm}^2}-\\Phi_{112\\mu\\mathrm{W}/\\mathrm{cm}^2}$ (mrad)');
ax2.set_ylim((-35,15));
# overall
fig.subplots_adjust(hspace=0);# join two figures
fig.subplots_adjust(left=rectLeft, right=rectRight, bottom=rectBot, top=rectTop);#set size


# first save
# I can get proper lines from PDF and proper writing, including TEX from SVG
fig.savefig('Raw_ThermalSweep.pdf', transparent=True);
fig.savefig('Raw_ThermalSweep.svg', transparent=True);
# then show the results
plt.show();


