# global imports
import matplotlib
import matplotlib.pyplot as plt
import numpy as np
from math import pi

#local imports
from LoadCSVMat import LoadCSVMat


########### Figure presets ########

plotSizeInch=(3.35,3.75);# about 8.5cm wide

###font
plt.rc('text', usetex=True);
plt.rc('font', family='serif');
plt.rc('font', serif='Computer Modern Roman');
plt.rc('xtick', labelsize=10.5);
plt.rc('ytick', labelsize=10.5);
plt.rc('axes', labelsize=10.5);

#line thickness ticks
axisLineWidthPt=0.850;
plt.rc('axes', linewidth=axisLineWidthPt);
plt.rc('lines', linewidth=axisLineWidthPt);
plt.rc('xtick.major', size=6.1, pad=2, width=axisLineWidthPt);
plt.rc('xtick.minor', size=4, pad=2, width=axisLineWidthPt);
plt.rc('ytick.major', size=6.1, pad=2, width=axisLineWidthPt);
plt.rc('ytick.minor', size=4, pad=2, width=axisLineWidthPt);

plt.rc('figure', figsize=plotSizeInch);#in inch

# keep fonts as fonts
matplotlib.rcParams['svg.fonttype'] = 'none';

############ Data load ########

# load the data
# extracted from Matlab file
# ...\VNA and mm-exp\Nb OverEtching\Sample1_Batch2\batch2_sample1_over-etched_15-04-2013\withAmp_29_04_2013\powerSweeps\4K2\Analyze_PowerSweepsAtFixedFq_PowerCorr.m
# the format is self-explanatory
dataMat=LoadCSVMat('4.2K_97.000GHz_TimeInSec_Pow_In_mW_Intensity_In_uWcm2_normLinTrace.csv');
derivMat=LoadCSVMat('4.2K_97.000GHz_TimeInSec_Intensity_In_uWcm2_normDeriv.csv');

timeRange=dataMat[:,0];
powRange=dataMat[:,1];
intRange=dataMat[:,2];
linRange=dataMat[:,3];

derivTimeRange=derivMat[:,0];
derivIntRange=derivMat[:,1];
derivNDerivRange=derivMat[:,2];

# find the time-range limits which corresponds to intensity limits used in the paper
# 112uW/cm2...500uW/cm2
indGoodRange=np.where( (intRange>=112) * (intRange<=500) )[0];#use multiplication to emulate &&
timeMin=timeRange[indGoodRange[0]];
timeMax=timeRange[indGoodRange[-1]];
########## Plotting ############

# box for the plot
#absolute measurements (convinent)
topMarginInch=0.087;
rightMarginInch=0.55;
leftMarginInch=0.65;
botMarginInch=0.32;
#relative to page size (needed by software)
rectLeft=leftMarginInch/plotSizeInch[0];
rectRight=1-rightMarginInch/plotSizeInch[0];
rectBot=botMarginInch/plotSizeInch[1];
rectTop=1-topMarginInch/plotSizeInch[1];

fig, (ax1, ax2)=plt.subplots(2, sharex=True);# can also be used for single-plots
############### subplot 1
ax1.plot(timeRange, linRange);

# y-axis
y1Lim=(1.10, 1.25); ax1.set_ylim(y1Lim);
#y1TickOffset=0;#offset of the first tick after minimum
#y1TickStep=1;
#y1Ticks=np.arange(start=y1Lim[0]+y1TickOffset, stop=y1Lim[1]+y1TickStep, step=y1TickStep);
#ax1.set_yticks(y1Ticks);
ax1.set_ylabel('$\\frac{T(\\nu,I,\\theta)}{T_{11\\, K}(\\nu)}$');

# left plot
ax1Left=ax1.twinx();
ax1Left.plot(timeRange, intRange);

# y-axis
y1LeftLim=(105,510); ax1Left.set_ylim(y1LeftLim);
ax1Left.set_ylabel('Intensity ($\\mu$W/cm$^2$)');

# x-axis, common
xLim=(timeMin,timeMax); ax1.set_xlim(xLim);#sec
#xTickOffset=0;#offset of the first tick after minimum
#xTickStep=1;
#xTicks=np.arange(start=xLim[0]+xTickOffset, stop=xLim[1]+xTickStep, step=xTickStep);
#ax1.set_xticks(xTicks);

############### subplot 2
ax2.plot(derivTimeRange, derivNDerivRange);

# x-axis
xLim=(timeMin,timeMax); ax2.set_xlim(xLim);#sec
#xTickOffset=0;#offset of the first tick after minimum
#xTickStep=1;
#xTicks=np.arange(start=xLim[0]+xTickOffset, stop=xLim[1]+xTickStep, step=xTickStep);
#ax1.set_xticks(xTicks);
ax1.set_xlabel('Time (sec)');


# y-axis
y2Lim=(0, 0.07); ax2.set_ylim(y2Lim);
#y1TickOffset=0;#offset of the first tick after minimum
#y1TickStep=1;
#y1Ticks=np.arange(start=y1Lim[0]+y1TickOffset, stop=y1Lim[1]+y1TickStep, step=y1TickStep);
#ax1.set_yticks(y1Ticks);
ax2.set_ylabel('$\\frac{dT/d\\theta}{T_{low}}$ (K$^{-1}$)');
ax2.set_xlabel('Time (s)');

################ overall
fig.subplots_adjust(hspace=0);# join two figures
fig.subplots_adjust(left=rectLeft, right=rectRight, bottom=rectBot, top=rectTop);#set size


# first save
# I can get proper lines from PDF and proper writing, including TEX from SVG
fig.savefig('Raw_SingleCalTrace.pdf', transparent=True);
fig.savefig('Raw_SingleCalTrace.svg', transparent=True);
# then show the results
plt.show();


